@@ -10,7 +10,7 @@ SUPPORTED = True
 try:
     # First, try lxml compatible with elementtree and looks faster a lot.
     # see also: http://getpython3.com/diveintopython3/xml.html
-    from lxml import etree
+    from lxml2 import etree
 except ImportError:
     try:
         import xml.etree.ElementTree as etree
@@ -24,25 +24,9 @@ except ImportError:
             SUPPORTED = False
 
 
-def etree_to_container(root, container):
-    """
-    Convert XML ElementTree to a collection of container objects.
-    """
-    tree = container()
-
-    if len(root):  # It has children.
-        # FIXME: Configuration item cannot have both attributes and
-        # values (list) at the same time in current implementation:
-        tree[root.tag] = [etree_to_container(c, container) for c in root]
-    else:
-        tree[root.tag] = container(**root.attrib)
-
-    return tree
-
-
 if SUPPORTED:
     def etree_getroot_fromstring(s):
-        return etree.fromstring(s).getroot()
+        return etree.ElementTree(etree.fromstring(s)).getroot()
 
     def etree_getroot_fromfile(f):
         return etree.parse(f).getroot()
@@ -56,6 +40,30 @@ else:
     etree_getroot_fromstring = etree_getroot_fromfile = _dummy_fun
 
 
+def etree_to_container(root, container):
+    """
+    Convert XML ElementTree to a collection of container objects.
+    """
+    tree = container()
+
+    if len(root):  # It has children.
+        # FIXME: Configuration item cannot have both attributes and
+        # values (list) at the same time in current implementation:
+        tree[root.tag] = container()
+        tree[root.tag]["children"] = [etree_to_container(c, container) for c
+                                      in root]
+        tree[root.tag]["attributes"] = container(**root.attrib)
+
+        if root.text.strip():
+            tree[root.tag]["text"] = root.text.strip()
+    else:
+        tree[root.tag]["attributes"] = container(**root.attrib)
+        if root.text.strip():
+            tree[root.tag]["text"] = root.text.strip()
+
+    return tree
+
+
 class XmlConfigParser(Base.ConfigParser):
 
     _type = "xml"
