@@ -1,18 +1,18 @@
 #
+# Copyright (C) 2011 - 2014 Red Hat, Inc.
 # Copyright (C) 2011 - 2013 Satoru SATOH <ssato redhat.com>
 # License: MIT
 #
 """Merge-able dict.
 """
 from __future__ import absolute_import
-
 from .compat import iteritems
 from . import utils as U
-# pylint: disable=C0103
-from .getset import get  # flake8: noqa
-# pylint: enable=C0103
+from . import parser as P
 
 import copy
+import functools
+import operator
 
 # TODO: Keep items' order:
 # from collections import OrderedDict as dict
@@ -26,6 +26,74 @@ MS_DICTS_AND_LISTS = "merge_dicts_and_lists"
 MERGE_STRATEGIES = (MS_REPLACE, MS_NO_REPLACE, MS_DICTS, MS_DICTS_AND_LISTS)
 
 
+def get(dic, path, seps=P.PATH_SEPS):
+    """
+    getter for nested dicts.
+
+    :param dic: Dict or dict-like object
+    :param path: Path expression to point object wanted
+    :param seps: Separator char candidates.
+
+    >>> d = dict(a=dict(b=dict(c=0, d=1)))
+    >>> get(d, '/') == (d, '')
+    True
+    >>> get(d, "/a/b/c")
+    (0, '')
+    >>> get(d, "a.b.d")
+    (1, '')
+    >>> get(d, "a.b") == ({'c': 0, 'd': 1}, '')
+    True
+    >>> get(d, "a.b.key_not_exist")[0] is None
+    True
+    >>> get('a str', 'a')[0] is None
+    True
+    """
+    try:
+        return (functools.reduce(operator.getitem, P.parse_path(path, seps),
+                                 dic),
+                '')
+    except (TypeError, KeyError) as e:
+        return (None, str(e))
+
+
+def _mk_nested_dic(path, val, seps=P.PATH_SEPS):
+    """
+    Make a nested dict iteratively.
+
+    :param path: Path expression to make a nested dict
+    :param val: Value to set
+    :param seps: Separator char candidates
+
+    >>> _mk_nested_dic("a.b.c", 1)
+    {'a': {'b': {'c': 1}}}
+    >>> _mk_nested_dic("/a/b/c", 1)
+    {'a': {'b': {'c': 1}}}
+    """
+    ret = None
+    for key in reversed(P.parse_path(path, seps)):
+        ret = {key: val if ret is None else ret.copy()}
+
+    return ret
+
+
+def set_(dic, path, val, seps=P.PATH_SEPS, strategy=None):
+    """
+    setter for nested dicts.
+
+    :param dic: MergeableDict instance or other dict-like objects support
+        recursive merge operations.
+    :param path: Path expression to point object wanted
+    :param seps: Separator char candidates.
+
+    >>> d = MergeableDict.create(dict(a=1, b=dict(c=2, )))
+    >>> set_(d, 'a.b.d', 3)
+    >>> d['a']['b']['d']
+    3
+    """
+    diff = _mk_nested_dic(path, val, seps)
+    dic.update(diff, strategy)
+
+
 def is_mergeabledict_or_dict(obj):
     """
     :param obj: Any object may be an instance of MergeableDict or dict.
